/**
 * Checks if the given input is a valid number and optionally, if it falls within a specific range.
 *
 * @param {T | T[]} data - T.
 * @param {(keyof T)[]} [fieldsToConcat] - Which fields of the object(s) to concatenate together
 * @param {string} [resultField] - The field to store the result in
 * @param {string} [separator] - The text to separate each field's value by. Default value for separator is " "
 * @returns {Object | Object[]} - Returns a new Object or array of Objects matching T, but with an extra key, provided by what is stored in resultField
 */
export function ConcatenateKeys(data, fieldsToConcat, resultField, separator) {
    let newData = data;
    if (Array.isArray(newData)) {
        newData = newData.map((dataItem) => {
            let newDataItem = dataItem;
            let textValue = "";
            fieldsToConcat.forEach((field, index) => (textValue += index > 0 ? (separator ? separator : " ") + dataItem[field] : dataItem[field]));
            newDataItem[resultField] = textValue;
            return newDataItem;
        });
    }
    if (typeof newData === "object") {
        let textValue = "";
        fieldsToConcat.forEach((field, index) => (textValue += index > 0 ? (separator ? separator : " ") + newData[field] : newData[field]));
        newData[resultField] = textValue;
    }
    return newData;
}
